@@ -4,7 +4,8 @@
 #' from the extent of a given sp object and a given resolution.
 #' @param w sp object; the spatial extent of this object is used to 
 #' create the regular SpatialPointsDataFrame.
-#' @param resolution numeric; resolution of the grid (in map units). 
+#' @param resolution numeric; resolution of the grid (in map units). If 
+#' resolution is not set, the grid will contain around 7500 points. (optional)
 #' @return The output of the function is a SpatialPointsDataFrame of regularly
 #' spaced points with the same extent as \code{w}. 
 #' @seealso \link{CreateDistMatrix}
@@ -19,6 +20,8 @@
 #' @export
 CreateGrid <- function (w, resolution)
 {
+  # w <- wo
+  # resolution <- 5000000
   TestSp(w)
   boundingBox <- bbox(w)
   if(is.null(resolution)){
@@ -28,21 +31,45 @@ CreateGrid <- function (w, resolution)
   rounder <- boundingBox %% resolution
   boundingBox[,1] <- boundingBox[,1] - rounder[,1]
   boundingBox[,2] <- boundingBox[,2] + resolution - rounder[,2]
-  boxCoordX <- seq(from = boundingBox[1,1] - resolution*10, 
-                   to = boundingBox[1,2]+resolution*10, 
+  boxCoordX <- seq(from = boundingBox[1,1] - resolution * 2, 
+                   to = boundingBox[1,2]+resolution * 2, 
                    by = resolution)
-  boxCoordY <- seq(from = boundingBox[2,1] - resolution * 10, 
-                   to = boundingBox[2,2] + resolution*10, 
+  boxCoordY <- seq(from = boundingBox[2,1] - resolution * 2, 
+                   to = boundingBox[2,2] + resolution * 2, 
                    by = resolution)
+  
   spatGrid <- expand.grid(boxCoordX, boxCoordY)
+  
   idSeq <- seq(1, nrow(spatGrid), 1)
+  
   spatGrid <- data.frame(ID = idSeq, 
                          COORDX = spatGrid[, 1], 
                          COORDY = spatGrid[, 2])
-
+  
   spatGrid <- SpatialPointsDataFrame(coords = spatGrid[ , c(2, 3)], 
                                      data = spatGrid, 
                                      proj4string = CRS(proj4string(w)))
+  
+  result <- tryCatch({
+    x <- spTransform(spatGrid, "+init=epsg:4326")
+    TRUE
+  }, warning = function(war) {
+    return(FALSE)
+  }, error = function(err) {
+    return(FALSE)
+  }, finally = {
+  })
+  
+  if (result==FALSE){
+    pref <- SpatialPoints(coords = data.frame(x = c(-179.9999,179.9999),
+                                              y =  c(89.9999,-89.9999) ),
+                          proj4string = CRS("+init=epsg:4326"))
+    a <- raster::extent(sp::spTransform(pref, proj4string(w)))
+    b <- raster::extent(spatGrid)
+    e <- c(b[1], b[2], a[3], a[4])
+    spatGrid <- raster::crop(spatGrid, e)
+  }
+  
   return(spatGrid)
 }
 
@@ -54,14 +81,19 @@ CreateGrid <- function (w, resolution)
 #' @param knownpts sp object; rows of the distance matrix.
 #' @param unknownpts sp object; columns of the distance matrix.
 #' @param bypassctrl logical; bypass the distance matrix size control (see Details).
-#' @details The function returns a full matrix of distances in meters using the 
-#' Great Circle distance (WGS84 ellipsoid) method. This is a wrapper
-#' for the \code{\link{spDists}} function. \cr.
+#' @param longlat	logical; if FALSE, Euclidean distance, if TRUE Great Circle 
+#' (WGS84 ellipsoid) distance.
+#' @details The function returns a full matrix of distances in meters. 
+#' This is a wrapper
+#' for the \code{\link{spDists}} function. \cr
 #' 
-#' If the matrix to compute is too large (more than 100,000,000 cells or more than 10,000,000 origins or destinations) 
-#' the function sends a confirmation message to warn users about the amount of RAM mobilized. 
+#' If the matrix to compute is too large (more than 100,000,000 cells, more than 
+#' 10,000,000 origins or more than 10,000,000 destinations) 
+#' the function sends a confirmation message to warn users about the amount of 
+#' RAM mobilized. 
 #' Use \code{bypassctrl} = TRUE to skip this control.
-#' @return A distance matrix, row names are \code{knownpts} row names, column names are \code{unknownpts} row names.
+#' @return A distance matrix, row names are \code{knownpts} row names, column 
+#' names are \code{unknownpts} row names.
 #' @seealso \link{CreateGrid}
 #' @examples 
 #' # Create a SpatialPointsDataFrame grid of spatMask extent and 200 meters 
@@ -69,8 +101,7 @@ CreateGrid <- function (w, resolution)
 #' data(spatData)
 #' mygrid <- CreateGrid(w = spatMask, resolution = 200)
 #' # Create a distance matrix between known spatPts and mygrid
-#' mymat <- CreateDistMatrix(knownpts = spatPts, unknownpts = mygrid, 
-#'                           bypassctrl = FALSE)
+#' mymat <- CreateDistMatrix(knownpts = spatPts, unknownpts = mygrid)
 #' mymat[1:5,1:5]
 #' nrow(spatPts)
 #' nrow(mygrid)
@@ -80,7 +111,8 @@ CreateGrid <- function (w, resolution)
 #' @export
 CreateDistMatrix  <- function(knownpts, 
                               unknownpts, 
-                              bypassctrl = FALSE)
+                              bypassctrl = FALSE, 
+                              longlat = TRUE)
 {
   TestSp(knownpts)
   TestSp(unknownpts)
@@ -114,12 +146,32 @@ CreateDistMatrix  <- function(knownpts,
     }
   }
   
-  matDist <- spDists(x = sp::spTransform(knownpts,"+init=epsg:4326"),
-                     y = sp::spTransform(unknownpts,"+init=epsg:4326"),
-                     longlat = TRUE) * 1000
+  if(methods::is(knownpts, "SpatialPolygons")){
+    knownpts <- SpatialPointsDataFrame(coordinates(knownpts), 
+                                       data = knownpts@data, 
+                                       proj4string = knownpts@proj4string)
+    
+    
+  }
+  if(methods::is(unknownpts, "SpatialPolygons")){
+    unknownpts <- SpatialPointsDataFrame(coordinates(unknownpts), 
+                                         data = unknownpts@data, 
+                                         proj4string = unknownpts@proj4string)
+  }
+  
+  if(sp::is.projected(knownpts)){
+    if(longlat){
+      knownpts <- sp::spTransform(knownpts,"+init=epsg:4326")
+      unknownpts <- sp::spTransform(unknownpts,"+init=epsg:4326")
+      matDist <- sp::spDists(x = knownpts, y = unknownpts, longlat = TRUE) * 1000
+    }else{
+      matDist <- sp::spDists(x = knownpts, y = unknownpts, longlat = FALSE)
+    }
+  }else{
+    matDist <- sp::spDists(x = knownpts, y = unknownpts, longlat = TRUE) * 1000
+  }
   
   dimnames(matDist) <- list(row.names(knownpts), row.names(unknownpts))
+  
   return(round(matDist, digits = 8))
 }
-
-
