@@ -26,10 +26,14 @@
 #' interaction function equals 0.5.
 #' @param beta numeric; impedance factor for the spatial interaction function.  
 #' @param resolution numeric; resolution of the output SpatialPointsDataFrame
-#'  (in map units). 
-#' @param nclass	numeric; a targeted number of classes (default to 8). Not used if breaks is set.
+#'  (in map units). If resolution is not set, the grid will contain around 7250 
+#'  points. (optional)
+#' @param nclass	numeric; a targeted number of classes (default to 8). Not used 
+#' if breaks is set.
 #' @param breaks numeric; a vector of values used to discretize the potentials. 
 #' @param mask SpatialPolygonsDataFrame; mask used to clip contours of potentials.
+#' @param bypassctrl logical; bypass the distance matrix size control (see 
+#' \code{\link{CreateDistMatrix}} Details).
 #' @return A SpatialPolygonsDataFrame is returned (see \link{rasterToContourPoly} Value). 
 #' @details 
 #' If var2 is provided the ratio between the potentials of var (numerator) 
@@ -81,7 +85,8 @@ quickStewart <- function(spdf, df, spdfid = NULL, dfid = NULL, var,
                          typefct = "exponential", span, 
                          beta, resolution = NULL, 
                          mask = NULL, 
-                         nclass = 8, breaks = NULL){
+                         nclass = 8, breaks = NULL, 
+                         bypassctrl = FALSE){
   # IDs  
   if (is.null(spdfid)){spdfid <- names(spdf@data)[1]}
   if (is.null(dfid)){dfid <- names(df)[1]}
@@ -98,7 +103,8 @@ quickStewart <- function(spdf, df, spdfid = NULL, dfid = NULL, var,
                  span = span, 
                  beta = beta, 
                  resolution = resolution, 
-                 mask = mask)
+                 mask = mask, 
+                 bypassctrl = bypassctrl)
   
   if(!is.null(var2)){
     pot2 <- stewart(knownpts = spdf, 
@@ -107,7 +113,8 @@ quickStewart <- function(spdf, df, spdfid = NULL, dfid = NULL, var,
                     span = span, 
                     beta = beta, 
                     resolution = resolution, 
-                    mask = mask)
+                    mask = mask, 
+                    bypassctrl = bypassctrl)
     ras <- rasterStewart(pot) / rasterStewart(pot2)
   }else{
     ras <- rasterStewart(pot)
