@@ -10,8 +10,8 @@
 #' units for which the function computes the estimates. Row names match the row 
 #' names of \code{knownpts} and column names match the row names of 
 #' \code{unknownpts}. \code{matdist} can contain any distance metric (time 
-#' distance or euclidean distance for example). If \code{matdist} is NULL, Great 
-#' Circle distances are used (with \code{\link{CreateDistMatrix}}).(optional)
+#' distance or euclidean distance for example). If \code{matdist} is NULL, the distance 
+#' matrix is built with \code{\link{CreateDistMatrix}}. (optional)
 #' @param varname character; name of the variable in the \code{knownpts} dataframe 
 #' from which potentials are computed. Quantitative variable with no negative values. 
 #' @param typefct character; spatial interaction function. Options are "pareto" 
@@ -25,9 +25,14 @@
 #' interaction function equals 0.5.
 #' @param beta numeric; impedance factor for the spatial interaction function.  
 #' @param resolution numeric; resolution of the output SpatialPointsDataFrame
-#'  (in map units). 
+#'  (in map units). If resolution is not set, the grid will contain around 7250 
+#'  points. (optional)
 #' @param mask sp object; the spatial extent of this object is used to 
 #' create the regularly spaced SpatialPointsDataFrame output. (optional)
+#' @param longlat	logical; if FALSE, Euclidean distance, if TRUE Great Circle 
+#' (WGS84 ellipsoid) distance.
+#' @param bypassctrl logical; bypass the distance matrix size control (see 
+#' \code{\link{CreateDistMatrix}} Details).
 #' @return SpatialPointsDataFrame with the computed potentials in a new field 
 #' named \code{OUTPUT}
 #' @seealso \link{rasterStewart}, \link{plotStewart}, \link{quickStewart},
@@ -69,7 +74,9 @@ stewart <- function(knownpts,
                     span,
                     beta,
                     resolution = NULL,
-                    mask = NULL)
+                    mask = NULL,
+                    bypassctrl = FALSE, 
+                    longlat = TRUE)
 {
   TestSp(knownpts)
   if (!is.null(unknownpts)){  
@@ -82,12 +89,14 @@ stewart <- function(knownpts,
       matdist <- UseDistMatrix(matdist =matdist, knownpts = knownpts, 
                                unknownpts =  unknownpts) 
     }else{
-      matdist <- CreateDistMatrix(knownpts = knownpts, unknownpts = unknownpts)
+      matdist <- CreateDistMatrix(knownpts = knownpts, unknownpts = unknownpts, 
+                                  bypassctrl = bypassctrl, longlat = longlat)
     }
   } else {
     unknownpts <- CreateGrid(w = if(is.null(mask)){knownpts} else {mask}, 
                              resolution = resolution) 
-    matdist <- CreateDistMatrix(knownpts = knownpts, unknownpts = unknownpts) 
+    matdist <- CreateDistMatrix(knownpts = knownpts, unknownpts = unknownpts, 
+                                bypassctrl = bypassctrl, longlat = longlat) 
   }
   
   
@@ -130,7 +139,7 @@ stewart <- function(knownpts,
 rasterStewart <- function(x, mask = NULL){
   gridded(x) <- TRUE
   r <- raster(x)
-  rasterx <- rasterize(x, r, field = 'OUTPUT')
+  rasterx <- rasterize(x[!is.na(x$OUTPUT),], r, field = 'OUTPUT')
   if(!is.null(mask)){
     TestSp(mask)
     rasterx <- mask(rasterx, mask = mask)
